# sb::App::Mobile
# == Author(s) : Takuya Otani <takuya.otani@gmail.com> ==
# == Copyright (C) 2005 SimpleBoxes/SerendipityNZ Ltd. ==

# ======================================
package sb::App::Mobile;
use strict;
use sb::Data ();
use sb::Template ();
use sb::Content ();
use sb::Content::Mobile ();
use sb::App::Receipt ();
use sb::App ();
use base qw( sb::App );
use vars qw( $VERSION );
$VERSION = '0.06';
# 0.06 [2007/08/17] modified for Serene Bach 3.*
# 0.05 [2007/04/12] changed run to output Content-Length correctly
# 0.04 [2006/12/15] changed _check_mode to fix a bug
# 0.03 [2005/10/18] changed load_template and run to pass TemplateManager object to sb::Content
# 0.02 [2005/10/15] changed _mobile_top, _mobile_comment_area, _mobile_trackback_area. Thanks Fuco!
# 0.01 [2005/08/15] changed _check_mode to extract entries correctly
# 0.00 [2005/06/09] generated
# --------------------------------------
# // defines / static variables
sub CONTENT_TYPE     (){ 'text/html' };
sub OUTPUT_CHARSET   (){ 'Shift_JIS' };
sub OUTPUT_CODE      (){ 'sjis' };
sub DEFAULT_TEMPLATE (){ 'default_mobile.html' };
# --------------------------------------
# // override base class
sub initialize
{
	my $self = shift;
	return $self->SUPER::initialize(@_);
}
sub run
{
	my $class = shift;
	my $self = $class->new(@_);
	my $param = sb::Content::MobileParam->new();
	my @entry = $self->_get_entries();
	if ($param->mode() eq 'com')
	{
		sb::App::Receipt->new(
			'time' => $self->time(),
			'mode' => 'com',
			'id'   => $self->cgi->value('entry_id'),
		)->issue();
	}
	else
	{
		my $content = sb::Content->new( 'main' => { sb::Content::Mobile::_init() } );
		$content->debug( $self->conf->value('debug_content') );
		my $out = $content->output(sb::Template->new($self->load_template()),
			'mode'      => 'mob',
			'css'       => undef,
			'page'      => ($param->mode() eq 'page' or $param->mode() eq 'cat') ? $param->page() : undef,
			'id'        => $self->cgi->value('eid'),
			'time'      => $self->time->data(),
			'entry'     => \@entry,
			'entry_num' => sb::Data->matched,
		);
		if ($self->lang->charcode ne OUTPUT_CODE)
		{
			$out = $self->lang->convert($out,OUTPUT_CODE,$self->lang->charcode);
		}
		$self->cgi->head(
			'type'    => CONTENT_TYPE,
			'charset' => OUTPUT_CHARSET,
			'length'  => ($content->debug) ? undef : length($out),
		);
		if ($content->error)
		{
			warn($content->error);
			$out .= '<pre>' . $content->error . '</pre>';
		}
		$self->output($out);
	}
}
sub load_template
{
	my $self = shift;
	my $base = undef;
	my $temp = undef;
	if ($self->conf->value('conf_mobile_temp') > -1)
	{
		$temp = sb::Data->load('Template','id'=>$self->conf->value('conf_mobile_temp'));
		$base = $temp->main() if ($temp);
	}
	$base = $self->SUPER::load_template('file'=>DEFAULT_TEMPLATE) if (!$base);
	return $base;
}
# --------------------------------------
# // private functions
sub _get_entries
{ # checking mode and extracting entries
	my $self = shift;
	my $param = sb::Content::MobileParam->get();
	my @entry = ();
	$param->mode('ent')  if ($self->cgi->value('eid') =~ /^\d+$/);      # entry
	$param->mode('cat')  if ($self->cgi->value('cid') =~ /^\d+$/);      # category
	$param->mode('com')  if ($self->cgi->value('entry_id') =~ /^\d+$/); # receiving comment
	$param->mode('page') if ($param->mode() eq ''); # page mode is default
	$param->page( int($self->cgi->value('page')) );
	$param->agent($self->cgi->user_agent());
	return if ($param->mode() eq 'com');
	# --- extract entries
	my $id   = undef;
	my $page = ($param->mode() eq 'ent') 
		? undef 
		: $param->page();
	my $num  = ($self->conf->value('conf_entry_disp') < 1) 
		? undef 
		: $self->conf->value('conf_entry_disp');
	$page = -1 if ($self->conf->value('conf_entry_disp') < 1);
	$id = int($self->cgi->value('eid')) if ($param->mode() eq 'ent');
	$id = int($self->cgi->value('cid')) if ($param->mode() eq 'cat');
	@entry = sb::Content::_extract_entry(
		'mode' => $param->mode(),
		'id'   => $id,
		'page' => $page,
		'conf' => $self->conf(),
		'cond' => undef,
		'num'  => $num,
	);
	return @entry if ($param->mode() ne 'ent');
	# --- select mode for entry mode
	if ($self->cgi->value('form') ne '')
	{ # comment form
		$param->mode('form');
		$param->page(0);
	}
	elsif ($self->cgi->value('com') ne '')
	{ # comments
		$param->mode('msg');
		$param->page( int($self->cgi->value('com')) );
	}
	elsif ($self->cgi->value('tb') ne '')
	{ # trackbacks
		$param->mode('tb');
		$param->page( int($self->cgi->value('tb')) );
	}
	elsif ($self->cgi->value('more') ne '')
	{ # entry sequel mode
		$param->more(1);
		$param->page( int($self->cgi->value('more')) );
	}
	return @entry;
}
1;
__END__
