# sb::Data::Trackback
# == Author(s) : Takuya Otani <takuya.otani@gmail.com> ==
# == Copyright (C) 2004 SimpleBoxes/SerendipityNZ Ltd. ==

# ======================================
package sb::Data::Trackback;
use strict;
use sb::Data::Object ();
use base qw( sb::Data::Object );
use vars qw( $VERSION );
$VERSION = '0.07';
# 0.07 [2007/08/14] added deprecated functions
# 0.06 [2007/08/07] changed default to initialize "icon"
# 0.05 [2007/08/04] added initializer
# 0.04 [2007/07/16] changed return to make them consistent
# 0.03 [2007/07/09] added name and subj to entitize the output properly
# 0.02 [2007/02/11] ported from biscuit
# 0.01 [2005/07/22] changed data structure to array
# 0.00 [2005/02/02] generated
# --------------------------------------
# // defines / static variables
sub LINK_TARGET (){ ' target="_blank"' }
sub SUMMARY_LENGTH (){ 300 }
# --------------------------------------
# // override base class - table
sub table
{
	my $self = shift;
	return (
		'id'   => 'uni_id',   # id
		'wid'  => 'id',       # weblog id (reserved)
		'eid'  => 'id',       # article id
		'stat' => 'int',      # status [-1:closed, 0:waiting, 1:opened, 2:entry isn't opened]
		'date' => 'date',     # received date
		'subj' => 'str(255)', # title of trackbacker
		'name' => 'str(255)', # site name of trackbacker
		'url'  => 'str(255)', # url of trackbacker
		'tz'   => 'zone',     # time zone
		'body' => 'text',     # trackback summary
		'host' => 'str(255)', # ip address of trackbacker
		'admn' => 'text',     # admin message (reserved)
		'icon' => 'id',       # icon (reserved)
		'out'  => 'str(255)', # number of outgoing (reserved)
	);
}
# --------------------------------------
# // initializer
BEGIN
{
	__PACKAGE__->init_accessor();
}
sub default
{ # default settings
	my $self  = shift;
	my %param = @_;
	$param{'wid'} |= 0;
	$param{'icon'} = -1 if ($param{'icon'} eq '');
	$self->SUPER::initialize(%param);
}
# --------------------------------------
# // public functions
sub name
{
	my $self = shift;
	$self->{'name'} = shift if (@_);
	return $self->entitize('name') if ($self->{'name'} =~ /[<>\"]/);
	return $self->{'name'};
}
sub subj
{
	my $self = shift;
	$self->{'subj'} = shift if (@_);
	return $self->entitize('subj') if ($self->{'subj'} =~ /[<>\"]/);
	return $self->{'subj'};
}
sub subj_with_url
{
	my $self = shift;
	my $target = LINK_TARGET;
	return '<a href="' . $self->url . '"' . $target . '>' . $self->subj . '</a>';
}
sub formatted_body
{
	my $self = shift;
	return sb::Text->new($self->body)->clip('length'=>SUMMARY_LENGTH);
}
sub get_size
{
	my $self = shift;
	return length($self->formatted_body) + length($self->subj_with_url);
}
# --------------------------------------
# // public functions - deprecated
sub formated_body
{
	formatted_body(@_);
}
# --------------------------------------
# // private functions
1;
__END__
