# sb::File::Uploader
# == Author(s) : Takuya Otani <takuya.otani@gmail.com> ==
# == Copyright (C) 2005 SimpleBoxes/SerendipityNZ Ltd. ==

# ======================================
package sb::File::Uploader;
use strict;
use sb::File ();
use base qw( sb::File );
use vars qw( $VERSION );
$VERSION = '0.04';
# 0.04 [2006/07/28] changed upload to fix a bug
# 0.03 [2006/07/04] got rid of "return( undef )"
# 0.02 [2006/03/17] changed bracket rule
# 0.01 [2006/03/12] changed _extension to fix a bug
# 0.00 [2005/10/27] generated
# --------------------------------------
# // defines / static variables
sub DEFAULT_PERMISSION (){ 0666 };
# --------------------------------------
# // public functions
sub set_param
{
	my $self = shift;
	my %param = (
		'label'  => undef,
		'header' => [],
		@_
	);
	my $label = $param{'label'};
	my @header = @{$param{'header'}};
	return if ($label eq '' or !@header);
	foreach (@header)
	{
		next if ($_ !~ /$label/);
		$param{'type'}     = $2 if ($_ =~ /(.*)Content-type:(.*)/i);
		$param{'filename'} = $2 if ($_ =~ /(.*)filename=(.*)/i);
		$param{'macbin'}   = ($_ =~ /application\/x-macbinary/i) ? 1 : undef;
		last;
	}
	$param{'type'} =~ tr/\x0D\x0A//d;
	$param{'type'} =~ s/\s//g;
	$param{'filename'} =~ tr/\"\x0D\x0A//d;
	$param{'filename'} =~ s/.*[:\/\\](.*)/$1/; # extract file name only
	$self->uploaded_name($param{'filename'});
	$self->uploaded_extension($self->_extension($param{'type'},$param{'filename'}));
	$self->mac_binary($param{'macbin'});
	return $self;
}
sub uploaded_name
{
	my $self = shift;
	$self->{'param'}->{'name'} = shift if (@_);
	return $self->{'param'}->{'name'};
}
sub uploaded_extension
{
	my $self = shift;
	$self->{'param'}->{'ext'} = shift if (@_);
	return $self->{'param'}->{'ext'};
}
sub mac_binary
{
	my $self = shift;
	$self->{'param'}->{'mac'} = shift if (@_);
	return $self->{'param'}->{'mac'};
}
sub upload
{
	my $self = shift;
	my $entity = shift;
	my $permission = shift;
	$permission = DEFAULT_PERMISSION if (!$permission);
	if ($self->mac_binary)
	{ # handle mac binary
		my $len = substr($entity,83,4);
		$len = unpack("%N",$len);
		$entity = substr($entity,128,$len);
	}
	$self->touch($permission);
	return $self->set_data($entity);
}
# --------------------------------------
# // private functions
sub _extension
{
	my $self = shift;
	my ($type,$name) = @_;
	my $type_from_name = $self->dictionary_class->content_type($name);
	return $self->dictionary_class->extension($type) 
		|| $self->dictionary_class->extension($type_from_name);
}
1;
__END__
