// spica javascript libraries - color.js
// == written by Takuya Otani <takuya.otani@gmail.com> ===
// == Copyright (C) 2006 SimpleBoxes/SerendipityNZ Ltd. ==

// [guideline]
// -- http://serennz.sakura.ne.jp/guidelines/js_en_000.txt
// -- http://serennz.sakura.ne.jp/guidelines/js_ja_000.txt

Spica.Color = function(code)
{
	var color = this._code(code);
	this.r = (color & 0xff0000) >>> 16;
	this.g = (color & 0x00ff00) >>> 8;
	this.b = (color & 0x0000ff);
	return this;
}
Spica.Color.prototype = {
	_code : function(code)
	{
		if (typeof code == 'object')
			return (code.r << 16) + (code.g << 8) + code.b;
		if (typeof code == 'string')
		{
			if (code.slice(0,4) == 'rgb(')
			{ // rgb(r,g,b)
				var cols = code.slice(4,code.length-1).split(',');
				return (parseInt(cols[0]) << 16) + (parseInt(cols[1]) << 8) + parseInt(cols[2]);
			}
			else if (code.indexOf('#') == 0)
			{ // #rgb or #rrggbb
				var number;
				if (code.match(/^#([0-9a-f])([0-9a-f])([0-9a-f])$/i))
					number = ['0x',RegExp.$1,RegExp.$1,RegExp.$2,RegExp.$2,RegExp.$3,RegExp.$3].join('');
				else
					number = ['0x',code.substr(1,6)].join('');
				return parseInt(number,16);
			}
		}
		return 0;
	},
	_range : function()
	{
		if (this.r > 0xff || this.r < 0) this.r = (this.r > 0xff) ? 0xff : 0;
		if (this.g > 0xff || this.g < 0) this.g = (this.g > 0xff) ? 0xff : 0;
		if (this.b > 0xff || this.b < 0) this.b = (this.b > 0xff) ? 0xff : 0;
		return this;
	},
	add : function(color)
	{
		this.r += color.r;
		this.g += color.g;
		this.b += color.b;
		return this;
	},
	subtract : function(color)
	{
		this.r -= color.r;
		this.g -= color.g;
		this.b -= color.b;
		return this;
	},
	multiply : function(num)
	{
		this.r = Math.floor(this.r * num);
		this.g = Math.floor(this.g * num);
		this.b = Math.floor(this.b * num);
		return this;
	},
	divide : function(num)
	{
		if (num == 0) return this;
		return this.multiply(1/num);
	},
	copy : function()
	{
		return new Spica.Color(this);
	},
	tint : function(obj)
	{
		if (!obj || !obj.style) return;
		obj.style.color = ['#',this.toString()].join('');
	},
	fill : function(obj)
	{
		if (!obj || !obj.style) return;
		obj.style.backgroundColor = ['#',this.toString()].join('');
	},
	toRgb : function()
	{
		var code = [this.r,this.g,this.b].join(',');
		return ['rgb(',code,')'].join('');
	},
	toString : function()
	{
		var str = this._range()._code(this).toString(16);
		for (var i=0,n=str.length;i<6-n;i++) str = ['0',str].join('');
		return str;
	}
};
Spica.ColorUtil = {};
Spica.ColorUtil.getColor = function(style)
{
	if (style == 'inherit') return 'none';
	if (style == 'transparent') return 'none';
	if (style.slice(0,4) == 'rgb(')
	{ // rgb(r,g,b,a)
		var cols = style.slice(4,style.length-1).split(',');
		if (cols[3] != '' && cols[3] == 0) return 'none';
	}
	return (new Spica.Color(style)).toRgb();
}
